@ECHO OFF
ECHO OFF
GOTO Begin
REM
REM     Program          :  DirUtil.bat
REM
REM     Version          :  1.0
REM     Started on       :  August 18, 2010
REM     Completed on     :  August 18, 2010
REM
REM     Description      :  Library of directory utilities
REM
REM     Required modules :  Str2Env.exe, StrComp.exe, StrIns.exe, StrPos.exe, FileUtil.bat
REM     Dos required     :  Dos 6.0 or later
REM
REM     Notes - usage    :  See help (/? parameter)
REM                         Setting DU_DEBUG environment variable to "Y", enable
REM                         on-screen commands echoing
REM                         Setting DEBUG environment variable to "Y", enable
REM                         on-screen commands echoing on return to caller
REM     References       :  None
REM
REM     Authors          :  J.Hubb - planning
REM                         J.Hubb - programming
REM                         J.Hubb - debug session
REM     Authors address  :  J.Hubb
REM                         Indigo skyline
REM                         A'DAAR channel
REM

:Begin
IF "%DU_DEBUG%" == "Y" ECHO ON
SET DU_VER=1.0

:ChkParams
IF "%1" == "" GOTO Help
IF "%1" == "/?" GOTO Help
FOR %%N IN (RealPath Ver) DO IF "%1" == "%%N" GOTO %1
GOTO FuncErr

REM
REM Function :  RealPath
REM Desc.    :  Translates the specified path in an absolute one
REM
REM Input    :  %2  relative or absolute path to be translated
REM             %3  var. name to be set
REM Output   :  environment variable named "%3"
REM
:RealPath
    IF "%3" == "" GOTO ParamErr
	CALL FileUtil NewFileName %TMP% DU bat DU_RP_F
    IF "%OS%" == "" GOTO RPWin9x
:RPWinNt
	%COMSPEC% /C "CD /D %2 && CD" > %TMP%\%DU_RP_F%.bat 2> NUL
    SET %3=
	SET /P %3=< %TMP%\%DU_RP_F%.bat
	GOTO RPEnd
:RPWin9x
	ECHO @ECHO OFF > %TMP%\%DU_RP_F%.bat
	ECHO %2 | STRPOS ":" | STRCOMP "=" "2" > NUL
	IF ERRORLEVEL 1 GOTO RPW9xNoDrive
	SET DU_RP_D=12
	ECHO %2 | STR2ENV "" DU_RP_D /U > NUL
	GOTO RPW9xGetPath
:RPW9xNoDrive
	SET DU_RP_D=12
	CD | STR2ENV "" DU_RP_D /U > NUL
:RPW9xGetPath
	CD %DU_RP_D% | STRINS 1 "CD " >> %TMP%\%DU_RP_F%.bat
	CD %2 > NUL
	CD %DU_RP_D% | STRINS 1 "SET %3=" >> %TMP%\%DU_RP_F%.bat
	CALL %TMP%\%DU_RP_F%.bat
	SET DU_RP_D=
:RPEnd
	DEL %TMP%\%DU_RP_F%.bat
	SET DU_RP_F=
    GOTO EndSub

REM
REM Function :  Ver
REM Desc.    :  Sets the specified variable to DirUtil version number
REM
REM Input    :  %2  var. name to be set
REM Output   :  environment variable named "%2"
REM
:Ver
    IF "%2" == "" GOTO ParamErr
    SET %2=%DU_VER%
    GOTO EndSub

:FuncErr
ECHO.
ECHO DirUtil.bat %DU_VER%.
ECHO.
ECHO Error: function "%1" does not exist.
ECHO Execution aborted.
PAUSE > NUL
GOTO End

:ParamErr
ECHO.
ECHO DirUtil.bat %DU_VER%.
ECHO.
ECHO Error: function "%1" called with wrong parameter number (see Help).
ECHO Execution aborted.
PAUSE > NUL
GOTO End

:Help
ECHO.
ECHO DirUtil.bat %DU_VER%; Open Source library on August 18, 2010 by J.Hubb.
ECHO.
ECHO Syntax:
ECHO   DIRUTIL {FunctionName} [FuncParam0 [FuncParam1 [...]]]
ECHO.
ECHO Calls the specified function {FunctionName} with optional
ECHO or requested parameters [FuncParam0], etc...
ECHO Defined functions are:
ECHO   RealPath {Path} {EnvVarName}
ECHO   Ver      {EnvVarName}
ECHO.
GOTO End

:End
SET DU_VER=

:EndSub
IF "%DEBUG%" == "Y" ECHO ON
